@@ -187,7 +187,7 @@ def OpenSpellsWindow (actor, table, level, diff, kit=0, gen=0, recommend=True, b
 
 		# chargen character seem to get more spells per level (this is kinda dirty hack)
 		# except sorcerers
-		if chargen and Class != 19 and not IWD2:
+		if chargen and not IWD2 and not Spellbook.HasSorcererBook (pc, Class):
 			SpellsSelectPointsLeft[i] += 1
 
 		# get all the spells of the given level
@@ -370,6 +370,10 @@ def ShowKnownSpells ():
 	GemRB.SetToken("number", str(SpellsSelectPointsLeft[SpellLevel]))
 	SpellsTextArea.SetText(17253)
 
+	if SpellsPickButton == 0:
+		# no recommendations at all
+		return
+
 	if Memorization == 1:
 		SpellsPickButton.SetState (IE_GUI_BUTTON_DISABLED)
 	else:
